@@ -1,5 +1,6 @@
 import time
 import warnings
+from base64 import decodestring
 
 try:
     import requests
@@ -26,6 +27,7 @@ class RequestsHttpConnection(Connection):
         string or a tuple. Any value will be passed into requests as `auth`.
     :arg use_ssl: use ssl for the connection if `True`
     :arg verify_certs: whether to verify SSL certificates
+    :arg ssl_show_warn: show warning when verify certs is disabled
     :arg ca_certs: optional path to CA bundle. By default standard requests'
         bundle will be used.
     :arg client_cert: path to the file containing the private key and the
@@ -33,23 +35,22 @@ class RequestsHttpConnection(Connection):
     :arg client_key: path to the file containing the private key if using
         separate cert and key files (client_cert will contain only the cert)
     :arg headers: any custom http headers to be add to requests
-    :arg http_compress: Use gzip compression
-    :arg cloud_id: The Cloud ID from ElasticCloud. Convenient way to connect to cloud instances.
+    :arg cloud_id: The Cloud ID from ElasticCloud. Convient way to connect to cloud instances.
         Other host connection params will be ignored.
     """
 
     def __init__(
         self,
         host="localhost",
-        port=None,
+        port=9200,
         http_auth=None,
         use_ssl=False,
         verify_certs=True,
+        ssl_show_warn=True,
         ca_certs=None,
         client_cert=None,
         client_key=None,
         headers=None,
-        http_compress=None,
         cloud_id=None,
         **kwargs
     ):
@@ -57,34 +58,33 @@ class RequestsHttpConnection(Connection):
             raise ImproperlyConfigured(
                 "Please install requests to use RequestsHttpConnection."
             )
-
-        # Initialize Session so .headers works before calling super().__init__().
-        self.session = requests.Session()
-        for key in list(self.session.headers):
-            self.session.headers.pop(key)
+        if cloud_id:
+            cluster_name, cloud_id = cloud_id.split(":")
+            url, es_uuid, kibana_uuid = (
+                decodestring(cloud_id.encode("utf-8")).decode("utf-8").split("$")
+            )
+            host = "%s.%s" % (es_uuid, url)
+            port = 9243
+            use_ssl = True
 
         super(RequestsHttpConnection, self).__init__(
-            host=host,
-            port=port,
-            use_ssl=use_ssl,
-            headers=headers,
-            http_compress=http_compress,
-            cloud_id=cloud_id,
-            **kwargs
+            host=host, port=port, use_ssl=use_ssl, **kwargs
         )
-
-        if not self.http_compress:
-            # Need to set this to 'None' otherwise Requests adds its own.
-            self.session.headers["accept-encoding"] = None
-
+        self.session = requests.Session()
+        self.session.headers = headers or {}
+        self.session.headers.setdefault("content-type", "application/json")
         if http_auth is not None:
             if isinstance(http_auth, (tuple, list)):
                 http_auth = tuple(http_auth)
             elif isinstance(http_auth, string_types):
                 http_auth = tuple(http_auth.split(":", 1))
             self.session.auth = http_auth
-
-        self.base_url = "%s%s" % (self.host, self.url_prefix,)
+        self.base_url = "http%s://%s:%d%s" % (
+            "s" if self.use_ssl else "",
+            host,
+            port,
+            self.url_prefix,
+        )
         self.session.verify = verify_certs
         if not client_key:
             self.session.cert = client_cert
@@ -98,25 +98,19 @@ class RequestsHttpConnection(Connection):
                 )
             self.session.verify = ca_certs
 
-        if self.use_ssl and not verify_certs:
+        if self.use_ssl and not verify_certs and ssl_show_warn:
             warnings.warn(
                 "Connecting to %s using SSL with verify_certs=False is insecure."
-                % self.host
+                % self.base_url
             )
 
     def perform_request(
         self, method, url, params=None, body=None, timeout=None, ignore=(), headers=None
     ):
         url = self.base_url + url
-        headers = headers or {}
         if params:
             url = "%s?%s" % (url, urlencode(params or {}))
 
-        orig_body = body
-        if self.http_compress and body:
-            body = self._gzip_compress(body)
-            headers["content-encoding"] = "gzip"
-
         start = time.time()
         request = requests.Request(method=method, headers=headers, url=url, data=body)
         prepared_request = self.session.prepare_request(request)
@@ -153,7 +147,7 @@ class RequestsHttpConnection(Connection):
                 method,
                 url,
                 response.request.path_url,
-                orig_body,
+                body,
                 duration,
                 response.status_code,
                 raw_data,
@@ -164,7 +158,7 @@ class RequestsHttpConnection(Connection):
             method,
             url,
             response.request.path_url,
-            orig_body,
+            body,
             response.status_code,
             raw_data,
             duration,
@@ -172,10 +166,6 @@ class RequestsHttpConnection(Connection):
 
         return response.status_code, response.headers, raw_data
 
-    @property
-    def headers(self):
-        return self.session.headers
-
     def close(self):
         """
         Explicitly closes connections
